===============================================
Welcome to Ironic UI's developer documentation!
===============================================

Introduction
============

The ironic UI is an OpenStack Horizon plugin that will allow users to view and
manage their ironic bare metal nodes, ports and drivers.

The documentation provided here is continually kept up-to-date based
on the latest code that has been committed, and may not represent the state of
the project at any specific prior release.

For information on any current or prior version of Ironic, see `the release
notes`_.

.. _the release notes: http://docs.openstack.org/releasenotes/ironic-ui/

For more information on ironic, see `the ironic documentation`_.

.. _the ironic documentation: http://docs.openstack.org/developer/ironic/

Administrator's Guide
=====================

.. toctree::
  :maxdepth: 1

  Introduction to ironic UI <readme>
  Introduction to ironic <http://docs.openstack.org/developer/ironic/deploy/user-guide.html>
  Installing the ironic UI <installation>
  Contributing <contributing>
  Release notes <http://docs.openstack.org/releasenotes/ironic-ui>
